@@ -42,7 +42,6 @@ format_ci <- function(CI_low,
                       width_high = width,
                       missing = "",
                       zap_small = FALSE) {
-
   # check proper defaults
   if (isTRUE(brackets)) {
     ci_brackets <- c("[", "]")
@@ -59,7 +58,7 @@ format_ci <- function(CI_low,
     # check if we have special handling, like "scientific" or "signif"
     # and then convert to numeric
     if (is.character(digits)) {
-      if (grepl("^scientific", digits)) {
+      if (startsWith(digits, "scientific")) {
         if (digits == "scientific") digits <- "scientific3"
         sig_digits <- as.numeric(gsub("scientific", "", digits, fixed = TRUE)) + 3
       } else {
