@@ -33,6 +33,11 @@ if (requiet("testthat") &&
     expect_identical(find_response(m1), "breaks")
   })
 
+  test_that("get_varcov", {
+    out <- get_varcov(m1)
+    expect_equal(colnames(out), names(coef(m1)))
+  })
+
   test_that("get_response", {
     expect_equal(get_response(m1), warpbreaks$breaks)
   })
